@@ -1,7 +1,6 @@
-import argparse
 import ast
 from fnmatch import fnmatch, fnmatchcase
-import os.path
+from pathlib import Path
 import pkgutil
 import re
 import string
@@ -12,7 +11,6 @@ from vulture import noqa
 from vulture import utils
 from vulture.config import make_config
 
-__version__ = "2.0"
 
 DEFAULT_CONFIDENCE = 60
 
@@ -49,8 +47,8 @@ def _match(name, patterns, case=True):
 
 def _is_test_file(filename):
     return _match(
-        os.path.abspath(filename),
-        ["*/test/*", "*/tests/*", "*/test*.py", "*/*_test.py", "*/*-test.py"],
+        filename.resolve(),
+        ["*/test/*", "*/tests/*", "*/test*.py", "*[-_]test.py"],
         case=False,
     )
 
@@ -65,7 +63,7 @@ def _ignore_import(filename, import_name):
     Ignore imports from __init__.py files since they're commonly used to
     collect objects from a package.
     """
-    return os.path.basename(filename) == "__init__.py" or import_name == "*"
+    return filename.name == "__init__.py" or import_name == "*"
 
 
 def _ignore_function(filename, function_name):
@@ -192,11 +190,12 @@ class Vulture(ast.NodeVisitor):
         self.ignore_names = ignore_names or []
         self.ignore_decorators = ignore_decorators or []
 
-        self.filename = ""
+        self.filename = Path()
         self.code = []
         self.found_dead_code_or_error = False
 
     def scan(self, code, filename=""):
+        filename = Path(filename)
         self.code = code.splitlines()
         self.noqa_lines = noqa.parse_noqa(self.code)
         self.filename = filename
@@ -211,9 +210,11 @@ class Vulture(ast.NodeVisitor):
 
         try:
             node = (
-                ast.parse(code, filename=self.filename, type_comments=True)
+                ast.parse(
+                    code, filename=str(self.filename), type_comments=True
+                )
                 if sys.version_info >= (3, 8)  # type_comments requires 3.8+
-                else ast.parse(code, filename=self.filename)
+                else ast.parse(code, filename=str(self.filename))
             )
         except SyntaxError as err:
             handle_syntax_error(err)
@@ -233,17 +234,19 @@ class Vulture(ast.NodeVisitor):
 
     def scavenge(self, paths, exclude=None):
         def prepare_pattern(pattern):
-            if not any(char in pattern for char in ["*", "?", "["]):
+            if not any(char in pattern for char in "*?["):
                 pattern = f"*{pattern}*"
             return pattern
 
         exclude = [prepare_pattern(pattern) for pattern in (exclude or [])]
 
-        def exclude_file(name):
-            return any(fnmatch(name, pattern) for pattern in exclude)
+        def exclude_path(path):
+            return _match(path, exclude, case=False)
+
+        paths = [Path(path) for path in paths]
 
         for module in utils.get_modules(paths):
-            if exclude_file(module):
+            if exclude_path(module):
                 self._log("Excluded:", module)
                 continue
 
@@ -262,12 +265,12 @@ class Vulture(ast.NodeVisitor):
 
         unique_imports = {item.name for item in self.defined_imports}
         for import_name in unique_imports:
-            path = os.path.join("whitelists", import_name) + "_whitelist.py"
-            if exclude_file(path):
+            path = Path("whitelists") / (import_name + "_whitelist.py")
+            if exclude_path(path):
                 self._log("Excluded whitelist:", path)
             else:
                 try:
-                    module_data = pkgutil.get_data("vulture", path)
+                    module_data = pkgutil.get_data("vulture", str(path))
                     self._log("Included whitelist:", path)
                 except OSError:
                     # Most imported modules don't have a whitelist.
@@ -283,7 +286,7 @@ class Vulture(ast.NodeVisitor):
             raise ValueError("min_confidence must be between 0 and 100.")
 
         def by_name(item):
-            return (item.filename.lower(), item.first_lineno)
+            return (str(item.filename).lower(), item.first_lineno)
 
         def by_size(item):
             return (item.size,) + by_name(item)
@@ -418,37 +421,6 @@ class Vulture(ast.NodeVisitor):
                     confidence=100,
                 )
 
-    def _handle_string(self, s):
-        """
-        Parse variable names in format strings:
-
-        '%(my_var)s' % locals()
-        '{my_var}'.format(**locals())
-        f'{my_var}'
-
-        """
-        # Old format strings.
-        self.used_names |= set(re.findall(r"\%\((\w+)\)", s))
-
-        def is_identifier(name):
-            return bool(re.match(r"[a-zA-Z_][a-zA-Z0-9_]*", name))
-
-        # New format strings.
-        parser = string.Formatter()
-        try:
-            names = [name for _, name, _, _ in parser.parse(s) if name]
-        except ValueError:
-            # Invalid format string.
-            names = []
-
-        for field_name in names:
-            # Remove brackets and their contents: "a[0][b].c[d].e" -> "a.c.e",
-            # then split the resulting string: "a.b.c" -> ["a", "b", "c"]
-            vars = re.sub(r"\[\w*\]", "", field_name).split(".")
-            for var in vars:
-                if is_identifier(var):
-                    self.used_names.add(var)
-
     def _define(
         self,
         collection,
@@ -508,8 +480,21 @@ class Vulture(ast.NodeVisitor):
         elif isinstance(node.ctx, ast.Load):
             self.used_names.add(node.attr)
 
+    def visit_BinOp(self, node):
+        """
+        Parse variable names in old format strings:
+
+        "%(my_var)s" % locals()
+        """
+        if (
+            isinstance(node.left, ast.Str)
+            and isinstance(node.op, ast.Mod)
+            and self._is_locals_call(node.right)
+        ):
+            self.used_names |= set(re.findall(r"%\((\w+)\)", node.left.s))
+
     def visit_Call(self, node):
-        """Count getattr/hasattr(x, "some_attr", ...) as usage of some_attr."""
+        # Count getattr/hasattr(x, "some_attr", ...) as usage of some_attr.
         if isinstance(node.func, ast.Name) and (
             (node.func.id == "getattr" and 2 <= len(node.args) <= 3)
             or (node.func.id == "hasattr" and len(node.args) == 2)
@@ -518,6 +503,49 @@ class Vulture(ast.NodeVisitor):
             if isinstance(attr_name_arg, ast.Str):
                 self.used_names.add(attr_name_arg.s)
 
+        # Parse variable names in new format strings:
+        # "{my_var}".format(**locals())
+        if (
+            isinstance(node.func, ast.Attribute)
+            and isinstance(node.func.value, ast.Str)
+            and node.func.attr == "format"
+            and any(
+                kw.arg is None and self._is_locals_call(kw.value)
+                for kw in node.keywords
+            )
+        ):
+            self._handle_new_format_string(node.func.value.s)
+
+    def _handle_new_format_string(self, s):
+        def is_identifier(name):
+            return bool(re.match(r"[a-zA-Z_][a-zA-Z0-9_]*", name))
+
+        parser = string.Formatter()
+        try:
+            names = [name for _, name, _, _ in parser.parse(s) if name]
+        except ValueError:
+            # Invalid format string.
+            names = []
+
+        for field_name in names:
+            # Remove brackets and their contents: "a[0][b].c[d].e" -> "a.c.e",
+            # then split the resulting string: "a.b.c" -> ["a", "b", "c"]
+            vars = re.sub(r"\[\w*\]", "", field_name).split(".")
+            for var in vars:
+                if is_identifier(var):
+                    self.used_names.add(var)
+
+    @staticmethod
+    def _is_locals_call(node):
+        """Return True if the node is `locals()`."""
+        return (
+            isinstance(node, ast.Call)
+            and isinstance(node.func, ast.Name)
+            and node.func.id == "locals"
+            and not node.args
+            and not node.keywords
+        )
+
     def visit_ClassDef(self, node):
         for decorator in node.decorator_list:
             if _match(
@@ -588,17 +616,6 @@ class Vulture(ast.NodeVisitor):
         elif isinstance(node.ctx, (ast.Param, ast.Store)):
             self._define_variable(node.id, node)
 
-    if sys.version_info < (3, 8):
-
-        def visit_Str(self, node):
-            self._handle_string(node.s)
-
-    else:
-
-        def visit_Constant(self, node):
-            if isinstance(node.value, str):
-                self._handle_string(node.value)
-
     def visit_While(self, node):
         self._handle_conditional_node(node, "while")
 
@@ -662,68 +679,6 @@ class Vulture(ast.NodeVisitor):
                 self.visit(value)
 
 
-def _parse_args():
-    def csv(exclude):
-        return exclude.split(",")
-
-    usage = "%(prog)s [options] PATH [PATH ...]"
-    version = f"vulture {__version__}"
-    glob_help = "Patterns may contain glob wildcards (*, ?, [abc], [!abc])."
-    parser = argparse.ArgumentParser(prog="vulture", usage=usage)
-    parser.add_argument(
-        "paths",
-        nargs="+",
-        metavar="PATH",
-        help="Paths may be Python files or directories. For each directory"
-        " Vulture analyzes all contained *.py files.",
-    )
-    parser.add_argument(
-        "--exclude",
-        metavar="PATTERNS",
-        type=csv,
-        help=f"Comma-separated list of paths to ignore (e.g.,"
-        f' "*settings.py,docs/*.py"). {glob_help} A PATTERN without glob'
-        f" wildcards is treated as *PATTERN*.",
-    )
-    parser.add_argument(
-        "--ignore-decorators",
-        metavar="PATTERNS",
-        type=csv,
-        help=f"Comma-separated list of decorators. Functions and classes using"
-        f' these decorators are ignored (e.g., "@app.route,@require_*").'
-        f" {glob_help}",
-    )
-    parser.add_argument(
-        "--ignore-names",
-        metavar="PATTERNS",
-        type=csv,
-        default=None,
-        help=f'Comma-separated list of names to ignore (e.g., "visit_*,do_*").'
-        f" {glob_help}",
-    )
-    parser.add_argument(
-        "--make-whitelist",
-        action="store_true",
-        help="Report unused code in a format that can be added to a"
-        " whitelist module.",
-    )
-    parser.add_argument(
-        "--min-confidence",
-        type=int,
-        default=0,
-        help="Minimum confidence (between 0 and 100) for code to be"
-        " reported as unused.",
-    )
-    parser.add_argument(
-        "--sort-by-size",
-        action="store_true",
-        help="Sort unused functions and classes by their lines of code.",
-    )
-    parser.add_argument("-v", "--verbose", action="store_true")
-    parser.add_argument("--version", action="version", version=version)
-    return parser.parse_args()
-
-
 def main():
     config = make_config()
     vulture = Vulture(
